@@ -3,7 +3,6 @@
 
 use libafl::{
     bolts::{ownedref::OwnedRefMut, tuples::Named},
-    executors::HasExecHooks,
     observers::{CmpMap, CmpObserver, CmpValues, Observer},
     state::HasMetadata,
     Error,
@@ -11,11 +10,8 @@ use libafl::{
 
 use serde::{Deserialize, Serialize};
 
-// TODO compile time flag
-/// The `CmpLogMap` W value
-pub const CMPLOG_MAP_W: usize = 65536;
-/// The `CmpLogMap` H value
-pub const CMPLOG_MAP_H: usize = 32;
+use crate::{CMPLOG_MAP_H, CMPLOG_MAP_W};
+
 /// The `CmpLog` map size
 pub const CMPLOG_MAP_SIZE: usize = CMPLOG_MAP_W * CMPLOG_MAP_H;
 
@@ -115,12 +111,8 @@ impl CmpMap for CmpLogMap {
     }
 
     fn reset(&mut self) -> Result<(), Error> {
-        self.headers = [CmpLogHeader {
-            hits: 0,
-            shape: 0,
-            kind: 0,
-        }; CMPLOG_MAP_W];
-        self.operands = [[CmpLogOperands(0, 0); CMPLOG_MAP_H]; CMPLOG_MAP_W];
+        self.headers = unsafe { core::mem::zeroed() };
+        // self.operands = unsafe { core::mem::zeroed() };
         Ok(())
     }
 }
@@ -153,11 +145,14 @@ pub struct CmpLogObserver<'a> {
     name: String,
 }
 
-impl<'a> CmpObserver<CmpLogMap> for CmpLogObserver<'a> {
+impl<'a, I, S> CmpObserver<CmpLogMap, I, S> for CmpLogObserver<'a>
+where
+    S: HasMetadata,
+{
     /// Get the number of usable cmps (all by default)
     fn usable_count(&self) -> usize {
         match &self.size {
-            None => self.map().len(),
+            None => self.map.as_ref().len(),
             Some(o) => *o.as_ref(),
         }
     }
@@ -171,19 +166,12 @@ impl<'a> CmpObserver<CmpLogMap> for CmpLogObserver<'a> {
     }
 }
 
-impl<'a> Observer for CmpLogObserver<'a> {}
-
-impl<'a, EM, I, S, Z> HasExecHooks<EM, I, S, Z> for CmpLogObserver<'a>
+impl<'a, I, S> Observer<I, S> for CmpLogObserver<'a>
 where
     S: HasMetadata,
+    Self: CmpObserver<CmpLogMap, I, S>,
 {
-    fn pre_exec(
-        &mut self,
-        _fuzzer: &mut Z,
-        _state: &mut S,
-        _mgr: &mut EM,
-        _input: &I,
-    ) -> Result<(), Error> {
+    fn pre_exec(&mut self, _state: &mut S, _input: &I) -> Result<(), Error> {
         self.map.as_mut().reset()?;
         unsafe {
             CMPLOG_ENABLED = 1;
@@ -191,13 +179,7 @@ where
         Ok(())
     }
 
-    fn post_exec(
-        &mut self,
-        _fuzzer: &mut Z,
-        state: &mut S,
-        _mgr: &mut EM,
-        _input: &I,
-    ) -> Result<(), Error> {
+    fn post_exec(&mut self, state: &mut S, _input: &I) -> Result<(), Error> {
         unsafe {
             CMPLOG_ENABLED = 0;
         }
